@@ -3,9 +3,8 @@ use v5.12;
 # check, convert and measure color values
 
 package Chart::Color::Value;
-our $VERSION = 'v2.402.2';
+our $VERSION = 'v2.403.0';
 use Carp;
-use POSIX ();
 
 sub check_rgb { # carp returns 1
     my (@rgb) = @_;
@@ -81,6 +80,7 @@ sub distance_rgb { # \@rgb, \@rgb --> $d
 sub distance_hsl { # \@hsl, \@hsl --> $d
     return carp  "need two triplets of hsl values in 2 arrays to compute hsl distance " if @_ != 2;
     my @delta_hsl = difference_hsl( $_[0], $_[1] );
+    return unless @delta_hsl == 3;
     sqrt($delta_hsl[0] ** 2 + $delta_hsl[1] ** 2 + $delta_hsl[2] ** 2); 
 }
 
@@ -151,8 +151,8 @@ sub _rgb_from_hsl { # float conversion
 my $half = 0.50000000000008;
 
 sub round {
-  $_[0] >= 0 ? POSIX::floor($_[0] + $half)
-             : POSIX::ceil($_[0] - $half)
+    $_[0] >= 0 ? int ($_[0] + $half)
+               : int ($_[0] - $half)
 }
 
 
